@@ -1,12 +1,8 @@
-# -*- coding: utf-8 -*-
 #
 #  This file is part of Sequana software
 #
 #  Copyright (c) 2016-2020 - Sequana Development Team
 #
-#  File author(s):
-#      Thomas Cokelaer <thomas.cokelaer@pasteur.fr>
-#
 #  Distributed under the terms of the 3-clause BSD license.
 #  The full license is in the LICENSE file, distributed with this software.
 #
@@ -474,6 +470,6 @@ class Taxonomy(metaclass=Singleton):
             if record not in self.records:
                 toadd.append(record)
 
-        with open(self.database, "a") as fout:
+        with open(self.database, "a") as fout: #pragma: no cover
             for record in toadd:
                 fout.write(tax.records[record]["raw"] + "//\n")
